package cn.estsh.i3plus.pojo.platform.bean;

import cn.estsh.i3plus.pojo.base.bean.BaseBean;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.databind.annotation.JsonSerialize;
import com.fasterxml.jackson.databind.ser.std.ToStringSerializer;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiParam;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.hibernate.annotations.DynamicInsert;
import org.hibernate.annotations.DynamicUpdate;

import javax.persistence.Column;
import javax.persistence.Entity;
import javax.persistence.Table;
import java.text.DecimalFormat;
import java.util.List;

/**
 * @Description : 用户详细
 * @Reference   :
 * @Author      : wei.peng
 * @Date        : 2018-10-22 16:58:43.910
 * @Modify      :
 **/
@Data
@Entity
@DynamicInsert
@DynamicUpdate
@EqualsAndHashCode(callSuper = true)
@Table(name="SYS_USER_INFO")
@Api(value="用户详细",description = "用户详细")
public class SysUserInfo extends BaseBean {

    @Column(name="NAME")
    @ApiParam(value ="名称" , access ="名称")
    private String name;

    @Column(name="USER_EMP_NO")
    @ApiParam(value ="工号")
    private String userEmpNo;

    @Column(name="LANGUAGE_CODE")
    @ApiParam(value ="用户语言")
    private String languageCode;

    @Column(name="USER_IMAGE_ID")
    @ApiParam(value ="用户图像" , example = "-1")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long userImageId;

    public Long getUserImageId() {
        if(userImageId != null) {
            return userImageId.longValue();
        }else{
            return userImageId;
        }
    }
 
    @Column(name="USER_SEX")
    @ApiParam(value ="性别（1.男，2.女）" , example ="1" , access ="性别（1.男，2.女）")
    private Integer userSex;
 
    @Column(name="USER_AGE")
    @ApiParam(value ="年龄" , example ="1" , access ="年龄")
    private Integer userAge;

    @Column(name="DEPARTMENT_ID")
    @ApiParam(value ="部门ID" , example ="-1")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long departmentId;

    public Long getDepartmentId() {
        if(departmentId != null) {
            return departmentId.longValue();
        }else{
            return departmentId;
        }
    }

    @Column(name="POSITION_ID")
    @ApiParam(value ="岗位ID" , example ="-1")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long positionId;

    public Long getPositionId() {
        if(positionId != null) {
            return positionId.longValue();
        }else{
            return positionId;
        }
    }

    @Column(name="ORGANIZE_ID")
    @ApiParam(value ="组织ID" , example = "0")
    @JsonSerialize(using = ToStringSerializer.class)
    private Long organizeId;

    public Long getOrganizeId() {
        if(organizeId != null) {
            return organizeId.longValue();
        }else{
            return organizeId;
        }
    }

    @Column(name="DEPARTMENT_NAMES_RDD")
    @ApiParam(value ="部门集合" , access ="部门集合")
    private String departmentNamesRdd;

    @Column(name="POSITION_NAMES_RDD")
    @ApiParam(value ="岗位集合" , access ="岗位集合")
    private String positionNamesRdd;

    @Column(name="ORGANIZE_NAMES_RDD")
    @ApiParam(value ="组织集合" , access ="组织集合")
    private String organizeNamesRdd;

    @Column(name="POSITION_NAME_RDD")
    @ApiParam(value ="岗位名称" , access ="岗位名称")
    private String positionNameRdd;

    @Column(name="DEPARTMENT_NAME_RDD")
    @ApiParam(value ="部门名称" , access ="部门名称")
    private String departmentNameRdd;

    @Column(name="ORGANIZE_NAME_RDD")
    @ApiParam(value ="组织名称" , access ="组织名称")
    private String organizeNameRdd;

    @Column(name="USER_ONLINE_STATUS")
    @ApiParam(value ="是否在线(枚举：1.在线，2.离线)" , example ="-1")
    private Integer userOnlineStatus;

    @Column(name="USER_INFO_STATUS")
    @ApiParam(value ="用户状态" , example ="-1")
    private Integer userInfoStatus;

    @Column(name="USER_LOGIN_LAST_DATE_TIME")
    @ApiParam(value ="用户最后登录时间")
    private String userLoginLastDateTime;

    @ApiParam(value ="用户所有部门信息")
    private transient List<Department> departmentList;

    @ApiParam(value ="用户所有岗位信息")
    private transient List<Position> positionList;

    @ApiParam(value ="用户组织信息")
    private transient Organize organize;

    @ApiParam(value = "岗位信息",access = "用户主岗位信息")
    private transient Position position;

    @JsonIgnore
    @ApiParam(value ="用户详细信息")
    private transient SysUser user;
}
